@@ -1,5 +1,5 @@
 .onLoad <- function(lib, pkg)
-   packageStartupMessage("Decon 1.1-1 loaded")
+   packageStartupMessage("Decon 1.2 loaded")
 
 .onUnload <- function(libpath)
     library.dynam.unload("decon",  libpath)
